/* ai-profile.c generated by valac 0.36.1.2-2a0ee, the Vala compiler
 * generated from ai-profile.vala, do not modify */

/* -*- Mode: vala; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * Copyright (C) 2010-2013 Robert Ancell
 * Copyright (C) 2013-2016 Michael Catanzaro
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
 * license.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_AI_PROFILE (ai_profile_get_type ())
#define AI_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AI_PROFILE, AIProfile))
#define AI_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AI_PROFILE, AIProfileClass))
#define IS_AI_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AI_PROFILE))
#define IS_AI_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AI_PROFILE))
#define AI_PROFILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AI_PROFILE, AIProfileClass))

typedef struct _AIProfile AIProfile;
typedef struct _AIProfileClass AIProfileClass;
typedef struct _AIProfilePrivate AIProfilePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _AIProfile {
	GObject parent_instance;
	AIProfilePrivate * priv;
};

struct _AIProfileClass {
	GObjectClass parent_class;
};

struct _AIProfilePrivate {
	gchar* _name;
	gchar* _protocol;
	gchar* _binary;
	gchar* _path;
	guint _delay_seconds;
	gchar** _easy_args;
	gint _easy_args_length1;
	gint __easy_args_size_;
	gchar** _normal_args;
	gint _normal_args_length1;
	gint __normal_args_size_;
	gchar** _hard_args;
	gint _hard_args_length1;
	gint __hard_args_size_;
	gchar** _easy_options;
	gint _easy_options_length1;
	gint __easy_options_size_;
	gchar** _normal_options;
	gint _normal_options_length1;
	gint __normal_options_size_;
	gchar** _hard_options;
	gint _hard_options_length1;
	gint __hard_options_size_;
	gchar** _easy_uci_go_options;
	gint _easy_uci_go_options_length1;
	gint __easy_uci_go_options_size_;
	gchar** _normal_uci_go_options;
	gint _normal_uci_go_options_length1;
	gint __normal_uci_go_options_size_;
	gchar** _hard_uci_go_options;
	gint _hard_uci_go_options_length1;
	gint __hard_uci_go_options_size_;
};


static gpointer ai_profile_parent_class = NULL;

GType ai_profile_get_type (void) G_GNUC_CONST;
#define AI_PROFILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_AI_PROFILE, AIProfilePrivate))
enum  {
	AI_PROFILE_DUMMY_PROPERTY,
	AI_PROFILE_NAME,
	AI_PROFILE_PROTOCOL,
	AI_PROFILE_BINARY,
	AI_PROFILE_PATH,
	AI_PROFILE_DELAY_SECONDS,
	AI_PROFILE_EASY_ARGS,
	AI_PROFILE_NORMAL_ARGS,
	AI_PROFILE_HARD_ARGS,
	AI_PROFILE_EASY_OPTIONS,
	AI_PROFILE_NORMAL_OPTIONS,
	AI_PROFILE_HARD_OPTIONS,
	AI_PROFILE_EASY_UCI_GO_OPTIONS,
	AI_PROFILE_NORMAL_UCI_GO_OPTIONS,
	AI_PROFILE_HARD_UCI_GO_OPTIONS
};
GList* ai_profile_load_ai_profiles (const gchar* filename);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
AIProfile* ai_profile_new (void);
AIProfile* ai_profile_construct (GType object_type);
static void ai_profile_set_name (AIProfile* self, const gchar* value);
static void ai_profile_set_protocol (AIProfile* self, const gchar* value);
static void ai_profile_set_binary (AIProfile* self, const gchar* value);
static gchar** ai_profile_load_array (GKeyFile* file, const gchar* name, const gchar* type, const gchar* difficulty, int* result_length1, GError** error);
static void ai_profile_set_easy_args (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_normal_args (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_hard_args (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_easy_options (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_normal_options (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_hard_options (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_easy_uci_go_options (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_normal_uci_go_options (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_hard_uci_go_options (AIProfile* self, gchar** value, int value_length1);
static void ai_profile_set_delay_seconds (AIProfile* self, guint value);
const gchar* ai_profile_get_binary (AIProfile* self);
static void ai_profile_set_path (AIProfile* self, const gchar* value);
const gchar* ai_profile_get_name (AIProfile* self);
const gchar* ai_profile_get_protocol (AIProfile* self);
const gchar* ai_profile_get_path (AIProfile* self);
guint ai_profile_get_delay_seconds (AIProfile* self);
gchar** ai_profile_get_easy_args (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup10 (gchar** self, int length);
gchar** ai_profile_get_normal_args (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup11 (gchar** self, int length);
gchar** ai_profile_get_hard_args (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup12 (gchar** self, int length);
gchar** ai_profile_get_easy_options (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup13 (gchar** self, int length);
gchar** ai_profile_get_normal_options (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup14 (gchar** self, int length);
gchar** ai_profile_get_hard_options (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup15 (gchar** self, int length);
gchar** ai_profile_get_easy_uci_go_options (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup16 (gchar** self, int length);
gchar** ai_profile_get_normal_uci_go_options (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup17 (gchar** self, int length);
gchar** ai_profile_get_hard_uci_go_options (AIProfile* self, int* result_length1);
static gchar** _vala_array_dup18 (gchar** self, int length);
static void ai_profile_finalize (GObject * obj);
static void _vala_ai_profile_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_ai_profile_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _g_object_unref0_ (gpointer var) {
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 158 "ai-profile.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_list_free (self);
#line 167 "ai-profile.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 82 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return self ? g_object_ref (self) : NULL;
#line 174 "ai-profile.c"
}


GList* ai_profile_load_ai_profiles (const gchar* filename) {
	GList* result = NULL;
	GList* profiles;
	GKeyFile* file;
	GKeyFile* _tmp0_;
	GKeyFile* _tmp7_;
	gsize _tmp8_;
	gchar** _tmp9_;
	GError * _inner_error_ = NULL;
#line 30 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 32 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	profiles = NULL;
#line 34 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = g_key_file_new ();
#line 34 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	file = _tmp0_;
#line 195 "ai-profile.c"
	{
		GKeyFile* _tmp1_;
		const gchar* _tmp2_;
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = file;
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp2_ = filename;
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_key_file_load_from_file (_tmp1_, _tmp2_, G_KEY_FILE_NONE, &_inner_error_);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 209 "ai-profile.c"
				goto __catch8_g_key_file_error;
			}
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 214 "ai-profile.c"
				goto __catch8_g_file_error;
			}
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			_g_key_file_unref0 (file);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			__g_list_free__g_object_unref0_0 (profiles);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_clear_error (&_inner_error_);
#line 37 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			return NULL;
#line 227 "ai-profile.c"
		}
	}
	goto __finally8;
	__catch8_g_key_file_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		e = _inner_error_;
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_inner_error_ = NULL;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp3_ = e;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp4_ = _tmp3_->message;
#line 41 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_warning ("ai-profile.vala:41: Failed to load AI profiles: %s", _tmp4_);
#line 42 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result = profiles;
#line 42 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_error_free0 (e);
#line 42 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_key_file_unref0 (file);
#line 42 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		return result;
#line 254 "ai-profile.c"
	}
	goto __finally8;
	__catch8_g_file_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		e = _inner_error_;
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_inner_error_ = NULL;
#line 46 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp5_ = e;
#line 46 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp6_ = _tmp5_->message;
#line 46 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_warning ("ai-profile.vala:46: Failed to load AI profiles: %s", _tmp6_);
#line 47 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result = profiles;
#line 47 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_error_free0 (e);
#line 47 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_key_file_unref0 (file);
#line 47 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		return result;
#line 280 "ai-profile.c"
	}
	__finally8:
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_key_file_unref0 (file);
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		__g_list_free__g_object_unref0_0 (profiles);
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_clear_error (&_inner_error_);
#line 35 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		return NULL;
#line 295 "ai-profile.c"
	}
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp7_ = file;
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp9_ = g_key_file_get_groups (_tmp7_, &_tmp8_);
#line 301 "ai-profile.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		name_collection = _tmp9_;
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		name_collection_length1 = _tmp8_;
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		for (name_it = 0; name_it < _tmp8_; name_it = name_it + 1) {
#line 313 "ai-profile.c"
			gchar* _tmp10_;
			gchar* name = NULL;
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			_tmp10_ = g_strdup (name_collection[name_it]);
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			name = _tmp10_;
#line 320 "ai-profile.c"
			{
				const gchar* _tmp11_;
				AIProfile* profile;
				AIProfile* _tmp12_;
				gchar* path;
				AIProfile* _tmp90_;
				const gchar* _tmp91_;
				gchar* _tmp92_;
				const gchar* _tmp93_;
#line 52 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp11_ = name;
#line 52 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				g_debug ("ai-profile.vala:52: Loading AI profile %s", _tmp11_);
#line 53 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp12_ = ai_profile_new ();
#line 53 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				profile = _tmp12_;
#line 338 "ai-profile.c"
				{
					AIProfile* _tmp13_;
					const gchar* _tmp14_;
					gchar* _tmp15_;
					GKeyFile* _tmp16_;
					const gchar* _tmp17_;
					gchar* _tmp18_;
					AIProfile* _tmp19_;
					gchar* _tmp20_;
					GKeyFile* _tmp21_;
					const gchar* _tmp22_;
					gchar* _tmp23_;
					AIProfile* _tmp24_;
					gchar** _tmp25_;
					GKeyFile* _tmp26_;
					const gchar* _tmp27_;
					gint _tmp28_;
					gchar** _tmp29_;
					gint _tmp25__length1;
					gint __tmp25__size_;
					AIProfile* _tmp30_;
					gchar** _tmp31_;
					GKeyFile* _tmp32_;
					const gchar* _tmp33_;
					gint _tmp34_;
					gchar** _tmp35_;
					gint _tmp31__length1;
					gint __tmp31__size_;
					AIProfile* _tmp36_;
					gchar** _tmp37_;
					GKeyFile* _tmp38_;
					const gchar* _tmp39_;
					gint _tmp40_;
					gchar** _tmp41_;
					gint _tmp37__length1;
					gint __tmp37__size_;
					AIProfile* _tmp42_;
					gchar** _tmp43_;
					GKeyFile* _tmp44_;
					const gchar* _tmp45_;
					gint _tmp46_;
					gchar** _tmp47_;
					gint _tmp43__length1;
					gint __tmp43__size_;
					AIProfile* _tmp48_;
					gchar** _tmp49_;
					GKeyFile* _tmp50_;
					const gchar* _tmp51_;
					gint _tmp52_;
					gchar** _tmp53_;
					gint _tmp49__length1;
					gint __tmp49__size_;
					AIProfile* _tmp54_;
					gchar** _tmp55_;
					GKeyFile* _tmp56_;
					const gchar* _tmp57_;
					gint _tmp58_;
					gchar** _tmp59_;
					gint _tmp55__length1;
					gint __tmp55__size_;
					AIProfile* _tmp60_;
					gchar** _tmp61_;
					GKeyFile* _tmp62_;
					const gchar* _tmp63_;
					gint _tmp64_;
					gchar** _tmp65_;
					gint _tmp61__length1;
					gint __tmp61__size_;
					AIProfile* _tmp66_;
					gchar** _tmp67_;
					GKeyFile* _tmp68_;
					const gchar* _tmp69_;
					gint _tmp70_;
					gchar** _tmp71_;
					gint _tmp67__length1;
					gint __tmp67__size_;
					AIProfile* _tmp72_;
					gchar** _tmp73_;
					GKeyFile* _tmp74_;
					const gchar* _tmp75_;
					gint _tmp76_;
					gchar** _tmp77_;
					gint _tmp73__length1;
					gint __tmp73__size_;
					AIProfile* _tmp78_;
					gboolean _tmp79_;
					GKeyFile* _tmp80_;
					const gchar* _tmp81_;
					gboolean _tmp82_;
#line 56 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp13_ = profile;
#line 56 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp14_ = name;
#line 56 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_name (_tmp13_, _tmp14_);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp16_ = file;
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp17_ = name;
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp18_ = g_key_file_get_value (_tmp16_, _tmp17_, "protocol", &_inner_error_);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp15_ = _tmp18_;
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 446 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 465 "ai-profile.c"
					}
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp19_ = profile;
#line 57 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_protocol (_tmp19_, _tmp15_);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp21_ = file;
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp22_ = name;
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp23_ = g_key_file_get_value (_tmp21_, _tmp22_, "binary", &_inner_error_);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp20_ = _tmp23_;
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 485 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 506 "ai-profile.c"
					}
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp24_ = profile;
#line 58 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_binary (_tmp24_, _tmp20_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp26_ = file;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp27_ = name;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp29_ = ai_profile_load_array (_tmp26_, _tmp27_, "arg", "easy", &_tmp28_, &_inner_error_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp25_ = _tmp29_;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp25__length1 = _tmp28_;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp25__size_ = _tmp25__length1;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 532 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 555 "ai-profile.c"
					}
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp30_ = profile;
#line 59 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_easy_args (_tmp30_, _tmp25_, _tmp25__length1);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp32_ = file;
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp33_ = name;
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp35_ = ai_profile_load_array (_tmp32_, _tmp33_, "arg", "normal", &_tmp34_, &_inner_error_);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp31_ = _tmp35_;
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp31__length1 = _tmp34_;
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp31__size_ = _tmp31__length1;
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 583 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 608 "ai-profile.c"
					}
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp36_ = profile;
#line 60 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_normal_args (_tmp36_, _tmp31_, _tmp31__length1);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp38_ = file;
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp39_ = name;
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp41_ = ai_profile_load_array (_tmp38_, _tmp39_, "arg", "hard", &_tmp40_, &_inner_error_);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp37_ = _tmp41_;
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp37__length1 = _tmp40_;
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp37__size_ = _tmp37__length1;
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 638 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 665 "ai-profile.c"
					}
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp42_ = profile;
#line 61 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_hard_args (_tmp42_, _tmp37_, _tmp37__length1);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp44_ = file;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp45_ = name;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp47_ = ai_profile_load_array (_tmp44_, _tmp45_, "option", "easy", &_tmp46_, &_inner_error_);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp43_ = _tmp47_;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp43__length1 = _tmp46_;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp43__size_ = _tmp43__length1;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 697 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 726 "ai-profile.c"
					}
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp48_ = profile;
#line 62 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_easy_options (_tmp48_, _tmp43_, _tmp43__length1);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp50_ = file;
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp51_ = name;
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp53_ = ai_profile_load_array (_tmp50_, _tmp51_, "option", "normal", &_tmp52_, &_inner_error_);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp49_ = _tmp53_;
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp49__length1 = _tmp52_;
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp49__size_ = _tmp49__length1;
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 760 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 791 "ai-profile.c"
					}
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp54_ = profile;
#line 63 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_normal_options (_tmp54_, _tmp49_, _tmp49__length1);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp56_ = file;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp57_ = name;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp59_ = ai_profile_load_array (_tmp56_, _tmp57_, "option", "hard", &_tmp58_, &_inner_error_);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp55_ = _tmp59_;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp55__length1 = _tmp58_;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp55__size_ = _tmp55__length1;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 827 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 860 "ai-profile.c"
					}
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp60_ = profile;
#line 64 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_hard_options (_tmp60_, _tmp55_, _tmp55__length1);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp62_ = file;
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp63_ = name;
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp65_ = ai_profile_load_array (_tmp62_, _tmp63_, "uci-go-option", "easy", &_tmp64_, &_inner_error_);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp61_ = _tmp65_;
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp61__length1 = _tmp64_;
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp61__size_ = _tmp61__length1;
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 898 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 933 "ai-profile.c"
					}
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp66_ = profile;
#line 65 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_easy_uci_go_options (_tmp66_, _tmp61_, _tmp61__length1);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp68_ = file;
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp69_ = name;
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp71_ = ai_profile_load_array (_tmp68_, _tmp69_, "uci-go-option", "normal", &_tmp70_, &_inner_error_);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp67_ = _tmp71_;
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp67__length1 = _tmp70_;
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp67__size_ = _tmp67__length1;
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 973 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 1010 "ai-profile.c"
					}
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp72_ = profile;
#line 66 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_normal_uci_go_options (_tmp72_, _tmp67_, _tmp67__length1);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp74_ = file;
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp75_ = name;
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp77_ = ai_profile_load_array (_tmp74_, _tmp75_, "uci-go-option", "hard", &_tmp76_, &_inner_error_);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp73_ = _tmp77_;
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp73__length1 = _tmp76_;
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__tmp73__size_ = _tmp73__length1;
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 1052 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 1091 "ai-profile.c"
					}
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp78_ = profile;
#line 67 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_hard_uci_go_options (_tmp78_, _tmp73_, _tmp73__length1);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp80_ = file;
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp81_ = name;
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp82_ = g_key_file_has_key (_tmp80_, _tmp81_, "delay-before-move", &_inner_error_);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp79_ = _tmp82_;
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp73_ = (_vala_array_free (_tmp73_, _tmp73__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 1131 "ai-profile.c"
							goto __catch9_g_key_file_error;
						}
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp73_ = (_vala_array_free (_tmp73_, _tmp73__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp20_);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (_tmp15_);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_object_unref0 (profile);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_free0 (name);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_g_key_file_unref0 (file);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						__g_list_free__g_object_unref0_0 (profiles);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 1172 "ai-profile.c"
					}
#line 69 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (_tmp79_) {
#line 1176 "ai-profile.c"
						gint _tmp83_;
						GKeyFile* _tmp84_;
						const gchar* _tmp85_;
						gint _tmp86_;
						AIProfile* _tmp87_;
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp84_ = file;
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp85_ = name;
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp86_ = g_key_file_get_integer (_tmp84_, _tmp85_, "delay-before-move", &_inner_error_);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp83_ = _tmp86_;
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp73_ = (_vala_array_free (_tmp73_, _tmp73__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_free0 (_tmp20_);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_free0 (_tmp15_);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 1216 "ai-profile.c"
								goto __catch9_g_key_file_error;
							}
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp73_ = (_vala_array_free (_tmp73_, _tmp73__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_free0 (_tmp20_);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_free0 (_tmp15_);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_object_unref0 (profile);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_free0 (name);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							_g_key_file_unref0 (file);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							__g_list_free__g_object_unref0_0 (profiles);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							g_clear_error (&_inner_error_);
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
							return NULL;
#line 1257 "ai-profile.c"
						}
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						_tmp87_ = profile;
#line 70 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						ai_profile_set_delay_seconds (_tmp87_, (guint) _tmp83_);
#line 1263 "ai-profile.c"
					}
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp73_ = (_vala_array_free (_tmp73_, _tmp73__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp67_ = (_vala_array_free (_tmp67_, _tmp67__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp61_ = (_vala_array_free (_tmp61_, _tmp61__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp55_ = (_vala_array_free (_tmp55_, _tmp55__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp49_ = (_vala_array_free (_tmp49_, _tmp49__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp43_ = (_vala_array_free (_tmp43_, _tmp43__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp31_ = (_vala_array_free (_tmp31_, _tmp31__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp25_ = (_vala_array_free (_tmp25_, _tmp25__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_free0 (_tmp20_);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_free0 (_tmp15_);
#line 1287 "ai-profile.c"
				}
				goto __finally9;
				__catch9_g_key_file_error:
				{
					GError* e = NULL;
					GError* _tmp88_;
					const gchar* _tmp89_;
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					e = _inner_error_;
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_inner_error_ = NULL;
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp88_ = e;
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp89_ = _tmp88_->message;
#line 74 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					g_warning ("ai-profile.vala:74: Error reading AI profiles: %s", _tmp89_);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_error_free0 (e);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_object_unref0 (profile);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_free0 (name);
#line 75 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					continue;
#line 1313 "ai-profile.c"
				}
				__finally9:
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_object_unref0 (profile);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_free0 (name);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_g_key_file_unref0 (file);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					__g_list_free__g_object_unref0_0 (profiles);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					g_clear_error (&_inner_error_);
#line 54 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					return NULL;
#line 1334 "ai-profile.c"
				}
#line 78 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp90_ = profile;
#line 78 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp91_ = _tmp90_->priv->_binary;
#line 78 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp92_ = g_find_program_in_path (_tmp91_);
#line 78 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				path = _tmp92_;
#line 79 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp93_ = path;
#line 79 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				if (_tmp93_ != NULL) {
#line 1348 "ai-profile.c"
					AIProfile* _tmp94_;
					const gchar* _tmp95_;
					AIProfile* _tmp96_;
					AIProfile* _tmp97_;
#line 81 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp94_ = profile;
#line 81 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp95_ = path;
#line 81 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					ai_profile_set_path (_tmp94_, _tmp95_);
#line 82 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp96_ = profile;
#line 82 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp97_ = _g_object_ref0 (_tmp96_);
#line 82 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					profiles = g_list_append (profiles, _tmp97_);
#line 1365 "ai-profile.c"
				}
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_g_free0 (path);
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_g_object_unref0 (profile);
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_g_free0 (name);
#line 1373 "ai-profile.c"
			}
		}
#line 50 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		name_collection = (_vala_array_free (name_collection, name_collection_length1, (GDestroyNotify) g_free), NULL);
#line 1378 "ai-profile.c"
	}
#line 86 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = profiles;
#line 86 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_g_key_file_unref0 (file);
#line 86 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1386 "ai-profile.c"
}


static gchar** ai_profile_load_array (GKeyFile* file, const gchar* name, const gchar* type, const gchar* difficulty, int* result_length1, GError** error) {
	gchar** result = NULL;
	gint count;
	gchar** options;
	gint _tmp11_;
	gchar** _tmp12_;
	gint options_length1;
	gint _options_size_;
	gchar** _tmp31_;
	gint _tmp31__length1;
	GError * _inner_error_ = NULL;
#line 89 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (file != NULL, NULL);
#line 89 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 89 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (type != NULL, NULL);
#line 89 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (difficulty != NULL, NULL);
#line 91 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	count = 0;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	while (TRUE) {
#line 1413 "ai-profile.c"
		gboolean _tmp0_;
		GKeyFile* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		gint _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gboolean _tmp8_;
		gboolean _tmp9_;
		gint _tmp10_;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = file;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp2_ = name;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp3_ = type;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp4_ = difficulty;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp5_ = count;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp6_ = g_strdup_printf ("%s-%s-%d", _tmp3_, _tmp4_, _tmp5_);
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp7_ = _tmp6_;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp8_ = g_key_file_has_key (_tmp1_, _tmp2_, _tmp7_, &_inner_error_);
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp9_ = _tmp8_;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_free0 (_tmp7_);
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = _tmp9_;
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				g_propagate_error (error, _inner_error_);
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				return NULL;
#line 1455 "ai-profile.c"
			} else {
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				g_clear_error (&_inner_error_);
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				return NULL;
#line 1463 "ai-profile.c"
			}
		}
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		if (!_tmp0_) {
#line 92 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			break;
#line 1470 "ai-profile.c"
		}
#line 93 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp10_ = count;
#line 93 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		count = _tmp10_ + 1;
#line 1476 "ai-profile.c"
	}
#line 95 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp11_ = count;
#line 95 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp12_ = g_new0 (gchar*, _tmp11_ + 1);
#line 95 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	options = _tmp12_;
#line 95 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	options_length1 = _tmp11_;
#line 95 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_options_size_ = options_length1;
#line 1488 "ai-profile.c"
	{
		gint i;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		i = 0;
#line 1493 "ai-profile.c"
		{
			gboolean _tmp13_;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			_tmp13_ = TRUE;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			while (TRUE) {
#line 1500 "ai-profile.c"
				gint _tmp15_;
				gint _tmp16_;
				gchar* _tmp17_;
				GKeyFile* _tmp18_;
				const gchar* _tmp19_;
				const gchar* _tmp20_;
				const gchar* _tmp21_;
				gint _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				gchar** _tmp27_;
				gint _tmp27__length1;
				gint _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				if (!_tmp13_) {
#line 1520 "ai-profile.c"
					gint _tmp14_;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					_tmp14_ = i;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					i = _tmp14_ + 1;
#line 1526 "ai-profile.c"
				}
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp13_ = FALSE;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp15_ = i;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp16_ = count;
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				if (!(_tmp15_ < _tmp16_)) {
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					break;
#line 1538 "ai-profile.c"
				}
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp18_ = file;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp19_ = name;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp20_ = type;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp21_ = difficulty;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp22_ = i;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp23_ = g_strdup_printf ("%s-%s-%d", _tmp20_, _tmp21_, _tmp22_);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp24_ = _tmp23_;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp25_ = g_key_file_get_value (_tmp18_, _tmp19_, _tmp24_, &_inner_error_);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp26_ = _tmp25_;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_g_free0 (_tmp24_);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp17_ = _tmp26_;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
					if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_propagate_error (error, _inner_error_);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						options = (_vala_array_free (options, options_length1, (GDestroyNotify) g_free), NULL);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 1572 "ai-profile.c"
					} else {
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						options = (_vala_array_free (options, options_length1, (GDestroyNotify) g_free), NULL);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						g_clear_error (&_inner_error_);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
						return NULL;
#line 1582 "ai-profile.c"
					}
				}
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp27_ = options;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp27__length1 = options_length1;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp28_ = i;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp29_ = _tmp17_;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp17_ = NULL;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_g_free0 (_tmp27_[_tmp28_]);
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp27_[_tmp28_] = _tmp29_;
#line 97 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_tmp30_ = _tmp27_[_tmp28_];
#line 96 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
				_g_free0 (_tmp17_);
#line 1603 "ai-profile.c"
			}
		}
	}
#line 99 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp31_ = options;
#line 99 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp31__length1 = options_length1;
#line 99 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 99 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp31__length1;
#line 1615 "ai-profile.c"
	}
#line 99 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp31_;
#line 99 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1621 "ai-profile.c"
}


AIProfile* ai_profile_construct (GType object_type) {
	AIProfile * self = NULL;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self = (AIProfile*) g_object_new (object_type, NULL);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return self;
#line 1631 "ai-profile.c"
}


AIProfile* ai_profile_new (void) {
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return ai_profile_construct (TYPE_AI_PROFILE);
#line 1638 "ai-profile.c"
}


const gchar* ai_profile_get_name (AIProfile* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_name;
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp0_;
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1653 "ai-profile.c"
}


static void ai_profile_set_name (AIProfile* self, const gchar* value) {
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (g_strcmp0 (value, ai_profile_get_name (self)) != 0) {
#line 1662 "ai-profile.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_free0 (self->priv->_name);
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_name = _tmp1_;
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "name");
#line 1675 "ai-profile.c"
	}
}


const gchar* ai_profile_get_protocol (AIProfile* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_protocol;
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp0_;
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1691 "ai-profile.c"
}


static void ai_profile_set_protocol (AIProfile* self, const gchar* value) {
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (g_strcmp0 (value, ai_profile_get_protocol (self)) != 0) {
#line 1700 "ai-profile.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_free0 (self->priv->_protocol);
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_protocol = _tmp1_;
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "protocol");
#line 1713 "ai-profile.c"
	}
}


const gchar* ai_profile_get_binary (AIProfile* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_binary;
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp0_;
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1729 "ai-profile.c"
}


static void ai_profile_set_binary (AIProfile* self, const gchar* value) {
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (g_strcmp0 (value, ai_profile_get_binary (self)) != 0) {
#line 1738 "ai-profile.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_free0 (self->priv->_binary);
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_binary = _tmp1_;
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "binary");
#line 1751 "ai-profile.c"
	}
}


const gchar* ai_profile_get_path (AIProfile* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_path;
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp0_;
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1767 "ai-profile.c"
}


static void ai_profile_set_path (AIProfile* self, const gchar* value) {
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (g_strcmp0 (value, ai_profile_get_path (self)) != 0) {
#line 1776 "ai-profile.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_g_free0 (self->priv->_path);
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_path = _tmp1_;
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "path");
#line 1789 "ai-profile.c"
	}
}


guint ai_profile_get_delay_seconds (AIProfile* self) {
	guint result;
	guint _tmp0_;
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_delay_seconds;
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp0_;
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1805 "ai-profile.c"
}


static void ai_profile_set_delay_seconds (AIProfile* self, guint value) {
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_delay_seconds (self) != value) {
#line 1814 "ai-profile.c"
		guint _tmp0_;
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_delay_seconds = _tmp0_;
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "delay-seconds");
#line 1822 "ai-profile.c"
	}
}


gchar** ai_profile_get_easy_args (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_easy_args;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_easy_args_length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 1847 "ai-profile.c"
	}
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1853 "ai-profile.c"
}


static gchar** _vala_array_dup10 (gchar** self, int length) {
	gchar** result;
	int i;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 1864 "ai-profile.c"
		gchar* _tmp0_;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 1870 "ai-profile.c"
	}
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1874 "ai-profile.c"
}


static void ai_profile_set_easy_args (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_easy_args (self, &old_value_length) != value) {
#line 1884 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup10 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_args = (_vala_array_free (self->priv->_easy_args, self->priv->_easy_args_length1, (GDestroyNotify) g_free), NULL);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_args = _tmp1_;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_args_length1 = _tmp1__length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__easy_args_size_ = self->priv->_easy_args_length1;
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "easy-args");
#line 1907 "ai-profile.c"
	}
}


gchar** ai_profile_get_normal_args (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_normal_args;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_normal_args_length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 1932 "ai-profile.c"
	}
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1938 "ai-profile.c"
}


static gchar** _vala_array_dup11 (gchar** self, int length) {
	gchar** result;
	int i;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 1949 "ai-profile.c"
		gchar* _tmp0_;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 1955 "ai-profile.c"
	}
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 1959 "ai-profile.c"
}


static void ai_profile_set_normal_args (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_normal_args (self, &old_value_length) != value) {
#line 1969 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup11 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_args = (_vala_array_free (self->priv->_normal_args, self->priv->_normal_args_length1, (GDestroyNotify) g_free), NULL);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_args = _tmp1_;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_args_length1 = _tmp1__length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__normal_args_size_ = self->priv->_normal_args_length1;
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "normal-args");
#line 1992 "ai-profile.c"
	}
}


gchar** ai_profile_get_hard_args (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_hard_args;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_hard_args_length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2017 "ai-profile.c"
	}
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2023 "ai-profile.c"
}


static gchar** _vala_array_dup12 (gchar** self, int length) {
	gchar** result;
	int i;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2034 "ai-profile.c"
		gchar* _tmp0_;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2040 "ai-profile.c"
	}
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2044 "ai-profile.c"
}


static void ai_profile_set_hard_args (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_hard_args (self, &old_value_length) != value) {
#line 2054 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup12 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_args = (_vala_array_free (self->priv->_hard_args, self->priv->_hard_args_length1, (GDestroyNotify) g_free), NULL);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_args = _tmp1_;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_args_length1 = _tmp1__length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__hard_args_size_ = self->priv->_hard_args_length1;
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "hard-args");
#line 2077 "ai-profile.c"
	}
}


gchar** ai_profile_get_easy_options (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_easy_options;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_easy_options_length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2102 "ai-profile.c"
	}
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2108 "ai-profile.c"
}


static gchar** _vala_array_dup13 (gchar** self, int length) {
	gchar** result;
	int i;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2119 "ai-profile.c"
		gchar* _tmp0_;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2125 "ai-profile.c"
	}
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2129 "ai-profile.c"
}


static void ai_profile_set_easy_options (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_easy_options (self, &old_value_length) != value) {
#line 2139 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup13 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_options = (_vala_array_free (self->priv->_easy_options, self->priv->_easy_options_length1, (GDestroyNotify) g_free), NULL);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_options = _tmp1_;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_options_length1 = _tmp1__length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__easy_options_size_ = self->priv->_easy_options_length1;
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "easy-options");
#line 2162 "ai-profile.c"
	}
}


gchar** ai_profile_get_normal_options (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_normal_options;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_normal_options_length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2187 "ai-profile.c"
	}
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2193 "ai-profile.c"
}


static gchar** _vala_array_dup14 (gchar** self, int length) {
	gchar** result;
	int i;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2204 "ai-profile.c"
		gchar* _tmp0_;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2210 "ai-profile.c"
	}
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2214 "ai-profile.c"
}


static void ai_profile_set_normal_options (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_normal_options (self, &old_value_length) != value) {
#line 2224 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup14 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_options = (_vala_array_free (self->priv->_normal_options, self->priv->_normal_options_length1, (GDestroyNotify) g_free), NULL);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_options = _tmp1_;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_options_length1 = _tmp1__length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__normal_options_size_ = self->priv->_normal_options_length1;
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "normal-options");
#line 2247 "ai-profile.c"
	}
}


gchar** ai_profile_get_hard_options (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_hard_options;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_hard_options_length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2272 "ai-profile.c"
	}
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2278 "ai-profile.c"
}


static gchar** _vala_array_dup15 (gchar** self, int length) {
	gchar** result;
	int i;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2289 "ai-profile.c"
		gchar* _tmp0_;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2295 "ai-profile.c"
	}
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2299 "ai-profile.c"
}


static void ai_profile_set_hard_options (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_hard_options (self, &old_value_length) != value) {
#line 2309 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup15 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_options = (_vala_array_free (self->priv->_hard_options, self->priv->_hard_options_length1, (GDestroyNotify) g_free), NULL);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_options = _tmp1_;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_options_length1 = _tmp1__length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__hard_options_size_ = self->priv->_hard_options_length1;
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "hard-options");
#line 2332 "ai-profile.c"
	}
}


gchar** ai_profile_get_easy_uci_go_options (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_easy_uci_go_options;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_easy_uci_go_options_length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2357 "ai-profile.c"
	}
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2363 "ai-profile.c"
}


static gchar** _vala_array_dup16 (gchar** self, int length) {
	gchar** result;
	int i;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2374 "ai-profile.c"
		gchar* _tmp0_;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2380 "ai-profile.c"
	}
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2384 "ai-profile.c"
}


static void ai_profile_set_easy_uci_go_options (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_easy_uci_go_options (self, &old_value_length) != value) {
#line 2394 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup16 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_uci_go_options = (_vala_array_free (self->priv->_easy_uci_go_options, self->priv->_easy_uci_go_options_length1, (GDestroyNotify) g_free), NULL);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_uci_go_options = _tmp1_;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_easy_uci_go_options_length1 = _tmp1__length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__easy_uci_go_options_size_ = self->priv->_easy_uci_go_options_length1;
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "easy-uci-go-options");
#line 2417 "ai-profile.c"
	}
}


gchar** ai_profile_get_normal_uci_go_options (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_normal_uci_go_options;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_normal_uci_go_options_length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2442 "ai-profile.c"
	}
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2448 "ai-profile.c"
}


static gchar** _vala_array_dup17 (gchar** self, int length) {
	gchar** result;
	int i;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2459 "ai-profile.c"
		gchar* _tmp0_;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2465 "ai-profile.c"
	}
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2469 "ai-profile.c"
}


static void ai_profile_set_normal_uci_go_options (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_normal_uci_go_options (self, &old_value_length) != value) {
#line 2479 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup17 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_uci_go_options = (_vala_array_free (self->priv->_normal_uci_go_options, self->priv->_normal_uci_go_options_length1, (GDestroyNotify) g_free), NULL);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_uci_go_options = _tmp1_;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_normal_uci_go_options_length1 = _tmp1__length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__normal_uci_go_options_size_ = self->priv->_normal_uci_go_options_length1;
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "normal-uci-go-options");
#line 2502 "ai-profile.c"
	}
}


gchar** ai_profile_get_hard_uci_go_options (AIProfile* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0_ = self->priv->_hard_uci_go_options;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp0__length1 = self->priv->_hard_uci_go_options_length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1_ = _tmp0_;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_tmp1__length1 = _tmp0__length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (result_length1) {
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		*result_length1 = _tmp1__length1;
#line 2527 "ai-profile.c"
	}
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = _tmp1_;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2533 "ai-profile.c"
}


static gchar** _vala_array_dup18 (gchar** self, int length) {
	gchar** result;
	int i;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	result = g_new0 (gchar*, length + 1);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	for (i = 0; i < length; i++) {
#line 2544 "ai-profile.c"
		gchar* _tmp0_;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = g_strdup (self[i]);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		result[i] = _tmp0_;
#line 2550 "ai-profile.c"
	}
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	return result;
#line 2554 "ai-profile.c"
}


static void ai_profile_set_hard_uci_go_options (AIProfile* self, gchar** value, int value_length1) {
	int old_value_length;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_return_if_fail (self != NULL);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	if (ai_profile_get_hard_uci_go_options (self, &old_value_length) != value) {
#line 2564 "ai-profile.c"
		gchar** _tmp0_;
		gint _tmp0__length1;
		gchar** _tmp1_;
		gint _tmp1__length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0_ = value;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp0__length1 = value_length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup18 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		_tmp1__length1 = _tmp0__length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_uci_go_options = (_vala_array_free (self->priv->_hard_uci_go_options, self->priv->_hard_uci_go_options_length1, (GDestroyNotify) g_free), NULL);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_uci_go_options = _tmp1_;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->_hard_uci_go_options_length1 = _tmp1__length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		self->priv->__hard_uci_go_options_size_ = self->priv->_hard_uci_go_options_length1;
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_object_notify ((GObject *) self, "hard-uci-go-options");
#line 2587 "ai-profile.c"
	}
}


static void ai_profile_class_init (AIProfileClass * klass) {
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	ai_profile_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_type_class_add_private (klass, sizeof (AIProfilePrivate));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_ai_profile_get_property;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_ai_profile_set_property;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	G_OBJECT_CLASS (klass)->finalize = ai_profile_finalize;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_BINARY, g_param_spec_string ("binary", "binary", "binary", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_PATH, g_param_spec_string ("path", "path", "path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_DELAY_SECONDS, g_param_spec_uint ("delay-seconds", "delay-seconds", "delay-seconds", 0, G_MAXUINT, (guint) 2, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_EASY_ARGS, g_param_spec_boxed ("easy-args", "easy-args", "easy-args", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_NORMAL_ARGS, g_param_spec_boxed ("normal-args", "normal-args", "normal-args", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_HARD_ARGS, g_param_spec_boxed ("hard-args", "hard-args", "hard-args", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_EASY_OPTIONS, g_param_spec_boxed ("easy-options", "easy-options", "easy-options", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_NORMAL_OPTIONS, g_param_spec_boxed ("normal-options", "normal-options", "normal-options", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_HARD_OPTIONS, g_param_spec_boxed ("hard-options", "hard-options", "hard-options", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_EASY_UCI_GO_OPTIONS, g_param_spec_boxed ("easy-uci-go-options", "easy-uci-go-options", "easy-uci-go-options", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_NORMAL_UCI_GO_OPTIONS, g_param_spec_boxed ("normal-uci-go-options", "normal-uci-go-options", "normal-uci-go-options", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AI_PROFILE_HARD_UCI_GO_OPTIONS, g_param_spec_boxed ("hard-uci-go-options", "hard-uci-go-options", "hard-uci-go-options", G_TYPE_STRV, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 2631 "ai-profile.c"
}


static void ai_profile_instance_init (AIProfile * self) {
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv = AI_PROFILE_GET_PRIVATE (self);
#line 19 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_delay_seconds = (guint) 2;
#line 2640 "ai-profile.c"
}


static void ai_profile_finalize (GObject * obj) {
	AIProfile * self;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_AI_PROFILE, AIProfile);
#line 15 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_g_free0 (self->priv->_name);
#line 16 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_g_free0 (self->priv->_protocol);
#line 17 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_g_free0 (self->priv->_binary);
#line 18 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	_g_free0 (self->priv->_path);
#line 20 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_easy_args = (_vala_array_free (self->priv->_easy_args, self->priv->_easy_args_length1, (GDestroyNotify) g_free), NULL);
#line 21 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_normal_args = (_vala_array_free (self->priv->_normal_args, self->priv->_normal_args_length1, (GDestroyNotify) g_free), NULL);
#line 22 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_hard_args = (_vala_array_free (self->priv->_hard_args, self->priv->_hard_args_length1, (GDestroyNotify) g_free), NULL);
#line 23 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_easy_options = (_vala_array_free (self->priv->_easy_options, self->priv->_easy_options_length1, (GDestroyNotify) g_free), NULL);
#line 24 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_normal_options = (_vala_array_free (self->priv->_normal_options, self->priv->_normal_options_length1, (GDestroyNotify) g_free), NULL);
#line 25 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_hard_options = (_vala_array_free (self->priv->_hard_options, self->priv->_hard_options_length1, (GDestroyNotify) g_free), NULL);
#line 26 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_easy_uci_go_options = (_vala_array_free (self->priv->_easy_uci_go_options, self->priv->_easy_uci_go_options_length1, (GDestroyNotify) g_free), NULL);
#line 27 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_normal_uci_go_options = (_vala_array_free (self->priv->_normal_uci_go_options, self->priv->_normal_uci_go_options_length1, (GDestroyNotify) g_free), NULL);
#line 28 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	self->priv->_hard_uci_go_options = (_vala_array_free (self->priv->_hard_uci_go_options, self->priv->_hard_uci_go_options_length1, (GDestroyNotify) g_free), NULL);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	G_OBJECT_CLASS (ai_profile_parent_class)->finalize (obj);
#line 2676 "ai-profile.c"
}


GType ai_profile_get_type (void) {
	static volatile gsize ai_profile_type_id__volatile = 0;
	if (g_once_init_enter (&ai_profile_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AIProfileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) ai_profile_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AIProfile), 0, (GInstanceInitFunc) ai_profile_instance_init, NULL };
		GType ai_profile_type_id;
		ai_profile_type_id = g_type_register_static (G_TYPE_OBJECT, "AIProfile", &g_define_type_info, 0);
		g_once_init_leave (&ai_profile_type_id__volatile, ai_profile_type_id);
	}
	return ai_profile_type_id__volatile;
}


static void _vala_ai_profile_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AIProfile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_AI_PROFILE, AIProfile);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	switch (property_id) {
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NAME:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_value_set_string (value, ai_profile_get_name (self));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_PROTOCOL:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_value_set_string (value, ai_profile_get_protocol (self));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_BINARY:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_value_set_string (value, ai_profile_get_binary (self));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_PATH:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_value_set_string (value, ai_profile_get_path (self));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_DELAY_SECONDS:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		g_value_set_uint (value, ai_profile_get_delay_seconds (self));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_EASY_ARGS:
#line 2729 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_easy_args (self, &length));
#line 2734 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NORMAL_ARGS:
#line 2740 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_normal_args (self, &length));
#line 2745 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_HARD_ARGS:
#line 2751 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_hard_args (self, &length));
#line 2756 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_EASY_OPTIONS:
#line 2762 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_easy_options (self, &length));
#line 2767 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NORMAL_OPTIONS:
#line 2773 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_normal_options (self, &length));
#line 2778 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_HARD_OPTIONS:
#line 2784 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_hard_options (self, &length));
#line 2789 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_EASY_UCI_GO_OPTIONS:
#line 2795 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_easy_uci_go_options (self, &length));
#line 2800 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NORMAL_UCI_GO_OPTIONS:
#line 2806 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_normal_uci_go_options (self, &length));
#line 2811 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_HARD_UCI_GO_OPTIONS:
#line 2817 "ai-profile.c"
		{
			int length;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			g_value_set_boxed (value, ai_profile_get_hard_uci_go_options (self, &length));
#line 2822 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 2826 "ai-profile.c"
		default:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 2832 "ai-profile.c"
	}
}


static void _vala_ai_profile_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AIProfile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_AI_PROFILE, AIProfile);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
	switch (property_id) {
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NAME:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		ai_profile_set_name (self, g_value_get_string (value));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_PROTOCOL:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		ai_profile_set_protocol (self, g_value_get_string (value));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_BINARY:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		ai_profile_set_binary (self, g_value_get_string (value));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_PATH:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		ai_profile_set_path (self, g_value_get_string (value));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_DELAY_SECONDS:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		ai_profile_set_delay_seconds (self, g_value_get_uint (value));
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_EASY_ARGS:
#line 2874 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_easy_args (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2881 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NORMAL_ARGS:
#line 2887 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_normal_args (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2894 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_HARD_ARGS:
#line 2900 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_hard_args (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2907 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_EASY_OPTIONS:
#line 2913 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_easy_options (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2920 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NORMAL_OPTIONS:
#line 2926 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_normal_options (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2933 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_HARD_OPTIONS:
#line 2939 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_hard_options (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2946 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_EASY_UCI_GO_OPTIONS:
#line 2952 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_easy_uci_go_options (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2959 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_NORMAL_UCI_GO_OPTIONS:
#line 2965 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_normal_uci_go_options (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2972 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		case AI_PROFILE_HARD_UCI_GO_OPTIONS:
#line 2978 "ai-profile.c"
		{
			gpointer boxed;
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			boxed = g_value_get_boxed (value);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
			ai_profile_set_hard_uci_go_options (self, boxed, (boxed == NULL) ? 0 : g_strv_length (boxed));
#line 2985 "ai-profile.c"
		}
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 2989 "ai-profile.c"
		default:
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/mcatanzaro/Projects/GNOME/gnome-chess/src/ai-profile.vala"
		break;
#line 2995 "ai-profile.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



